@@ -15,7 +15,7 @@ test_that(" throws error with invalid arguments", {
   skip_if(Sys.getenv("CENSUS_API_KEY") == "")
   
   # Incorrect state
-  expect_error(krieger(state = "AB", year = 2020))
+  expect_error(krieger(state = "AB", year = 2020, quiet = TRUE))
   
 }
 )   
@@ -24,11 +24,9 @@ test_that("krieger works", {
   
   skip_if(Sys.getenv("CENSUS_API_KEY") == "")
   
-  expect_message(krieger(state = "DC", year = 2020))
+  expect_silent(krieger(state = "DC", year = 2020))
   
   expect_silent(krieger(state = "DC", year = 2020, quiet = TRUE))
   
-  expect_silent(krieger(state = "DC", year = 2020, quiet = TRUE)) 
-  
 }
 )  
